[Bf-blender-cvs] [07ec03d4f80] greasepencil-object: Rename Panel Primitives to Shapes

Antonio Vazquez noreply at git.blender.org
Mon Oct 16 09:33:34 CEST 2017


Commit: 07ec03d4f8024dbff0c685321cd1376c03bb62cc
Author: Antonio Vazquez
Date:   Mon Oct 16 09:33:23 2017 +0200
Branches: greasepencil-object
https://developer.blender.org/rB07ec03d4f8024dbff0c685321cd1376c03bb62cc

Rename Panel Primitives to Shapes

The "Primitive" name can be confusing. It's better to use "Shapes" because these options are to add new strokes with a predefined shape, not a new GP object with this shape.

===================================================================

M	release/scripts/startup/bl_ui/properties_grease_pencil_common.py
M	source/blender/editors/gpencil/gpencil_primitive.c

===================================================================

diff --git a/source/blender/editors/gpencil/gpencil_primitive.c b/source/blender/editors/gpencil/gpencil_primitive.c
index 0dc1fd577cf..24d08807e12 100644
--- a/source/blender/editors/gpencil/gpencil_primitive.c
+++ b/source/blender/editors/gpencil/gpencil_primitive.c
@@ -721,9 +721,9 @@ void GPENCIL_OT_primitive(wmOperatorType *ot)
 	};
 
 	/* identifiers */
-	ot->name = "Grease Pencil Primitives";
+	ot->name = "Grease Pencil Shapes";
 	ot->idname = "GPENCIL_OT_primitive";
-	ot->description = "Create primitves grease pencil strokes";
+	ot->description = "Create predefined grease pencil stroke shapes";
 	
 	/* callbacks */
 	ot->invoke = gpencil_primitive_invoke;
@@ -736,7 +736,7 @@ void GPENCIL_OT_primitive(wmOperatorType *ot)
 	
 	/* properties */
 	RNA_def_int(ot->srna, "edges", 4, MIN_EDGES, MAX_EDGES, "Edges", "Number of polygon edges", MIN_EDGES, MAX_EDGES);
-	RNA_def_enum(ot->srna, "type", primitive_type, GP_STROKE_BOX, "Type", "Type of primitive");
+	RNA_def_enum(ot->srna, "type", primitive_type, GP_STROKE_BOX, "Type", "Type of shape");
 }
 
 /* *************************************************************** */



More information about the Bf-blender-cvs mailing list
diff --git a/release/scripts/startup/bl_ui/properties_grease_pencil_common.py b/release/scripts/startup/bl_ui/properties_grease_pencil_common.py
index 5d81ff816b2..9b360736bbc 100644
--- a/release/scripts/startup/bl_ui/properties_grease_pencil_common.py
+++ b/release/scripts/startup/bl_ui/properties_grease_pencil_common.py
@@ -87,7 +87,7 @@ class GreasePencilDrawingToolsPanel:
         layout = self.layout
         if context.space_data.type == 'VIEW_3D':
             if context.active_object and context.active_object.mode == 'GPENCIL_PAINT':
-                layout.label(text="Primitives")
+                layout.label(text="Shapes")
             else:
                 layout.label(text="Measurement")
         else:
@@ -102,7 +102,7 @@ class GreasePencilDrawingToolsPanel:
 
         col = layout.column(align=True)
 
         # XXX: Primitve tools maybe need a panel
         if is_3d_view:
             col.operator("gpencil.primitive", text="Rectangle", icon='UV_FACESEL').type = 'BOX'
             col.operator("gpencil.primitive", text="Circle", icon='ANTIALIASED').type = 'CIRCLE'
@@ -102,7 +102,7 @@ class GreasePencilDrawingToolsPanel:
         col = layout.column(align=True)
 
-        # XXX: Primitve tools maybe need a panel
+        # XXX: Shapes tools maybe need a panel
         if is_3d_view:
             col.operator("gpencil.primitive", text="Rectangle", icon='UV_FACESEL').type = 'BOX'